@@ -43,8 +43,7 @@ class save:
         self.encoding: Encoding = Enum(
             "Encoding", ["NONE", "JSON", "BINARY", "CRYPTOGRAPHY"]
         )
-        self.storage: Storage = Enum(
-            "Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
+        self.storage: Storage = Enum("Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
         self.saveModules = {}
         self.settings = {
             "FTP": {"Name": "", "Password": ""},
@@ -68,8 +67,7 @@ class save:
             module = module[:-3]  # remove .py
             # Attempt to load the module
             try:
-                mdl = importlib.import_module(
-                    f"{SaveModules.__package__}.{module}")
+                mdl = importlib.import_module(f"{SaveModules.__package__}.{module}")
                 self.saveModules[module] = mdl.load()
             except (AttributeError, ModuleNotFoundError) as e:
                 Message.warn(
@@ -118,8 +116,7 @@ class save:
             )
 
             if data.get("Name") == "" or not correct:
-                data["Name"] = input(
-                    "Please enter your username for the FTP server: ")
+                data["Name"] = input("Please enter your username for the FTP server: ")
 
             data["Password"] = getpass.getpass(
                 "Please enter your password for the FTP server: "
@@ -161,8 +158,7 @@ class save:
         """
 
         key = self.enc.GetKey()  # get the byte version
-        self.settings["Passcode"] = key.decode(
-            "utf-8")  # store the byte as string
+        self.settings["Passcode"] = key.decode("utf-8")  # store the byte as string
 
         # save the data
         self.Save(
@@ -196,22 +192,19 @@ class save:
 
             if code.value == 2:
                 # simple json encode
-                result = json.dumps(
-                    result) if not decode else json.loads(result)
+                result = json.dumps(result) if not decode else json.loads(result)
                 continue
 
             if code.value == 3:
                 # simple byte encode
-                result = pickle.dumps(
-                    result) if not decode else pickle.loads(result)
+                result = pickle.dumps(result) if not decode else pickle.loads(result)
                 rBytes = True
 
             if code.value == 4:
                 Passcode = self.settings.get("Passcode")
 
                 if Passcode == "MGNiYzY2MTFmNTU0MGJkMDgwOWEzODhkYzk1YTYxNWI=":
-                    Message.warn(
-                        "WARNING: DEFAULT PASSCODE IN USE!", colour="red")
+                    Message.warn("WARNING: DEFAULT PASSCODE IN USE!", colour="red")
 
                 # Get passcode if not exists
                 if Passcode is None or Passcode == "":
@@ -260,8 +253,7 @@ class save:
 
         data, wByte = self.__CodeData(data, encoding)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         return module.WriteData(data, path, wByte)
 
     def Read(self, path: str, encoding: typing.List = None) -> any:
@@ -275,8 +267,7 @@ class save:
             any: The data in the file
         """
         path, storage, encoding = self.__GetFileInformation(path, encoding)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
 
         rBytes = False
         for item in encoding:
@@ -302,8 +293,7 @@ class save:
         if storage is None:
             path, storage = self.__TranslateStorage(path)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         return module.MakeFolders(path)
 
@@ -314,8 +304,7 @@ class save:
             path (str): The path to remove that file
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         module.DeleteFile(path)
 
@@ -326,7 +315,6 @@ class save:
             path (str): The path to remove the folder
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         module.DeleteFolder(path)
